pixie16 package
===============

The package consists of several modules and subpackages.

Subpackages
-----------

Currently there are two subpackages for reading binary data such as
list mode data and settings data and another package for UI elements
that are used in the Qt-based interfaces provided to, for example,
look at binary data files.

.. toctree::
   :maxdepth: 4

   pixie16.read
   pixie16.ui

Submodules
----------

pixie16.C\_library\_app module
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.C_library_app
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.C\_library\_sys module
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.C_library_sys
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.analyze module
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.analyze
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.config module
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.config
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.control module
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.control
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.plot module
^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.plot
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.scan module
^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.scan
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.pipeline module
^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.pipeline
   :members:
   :undoc-members:
   :show-inheritance:

pixie16.tasks module
^^^^^^^^^^^^^^^^^^^^

.. automodule:: pixie16.tasks
   :members:
   :undoc-members:
   :show-inheritance:
